#
# Copyright (c) 2008-2010 Revolution Analytics
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

.onLoad <- function(lib, pkg) {
  if (interactive()) {
    packageStartupMessage('foreach: simple, scalable parallel programming from Revolution Analytics\n',
        'Use Revolution R for scalability, fault tolerance and more.\n',
        'http://www.revolutionanalytics.com', domain=NA, appendLF=TRUE)
  }
}
